==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3.md <==
# AmazonBraketSimulator3


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')
```



| Illustration | AmazonBraketSimulator3 | AmazonBraketSimulator3Card | AmazonBraketSimulator3Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3.png) | ![illustration for AmazonBraketSimulator3](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3.Local.png) | ![illustration for AmazonBraketSimulator3Card](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3Card.Local.png) | ![illustration for AmazonBraketSimulator3Group](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3Group.Local.png) |




## AmazonBraketSimulator3

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3('AmazonBraketSimulator3', 'Amazon Braket Simulator3', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3('AmazonBraketSimulator3', 'Amazon Braket Simulator3', 'an optional tech label')
@enduml
```

## AmazonBraketSimulator3Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Card
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Card('AmazonBraketSimulator3Card', 'Amazon Braket Simulator3 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Card
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Card('AmazonBraketSimulator3Card', 'Amazon Braket Simulator3 Card', 'an optional description')
@enduml
```

## AmazonBraketSimulator3Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Group
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Group('AmazonBraketSimulator3Group', 'Amazon Braket Simulator3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Group
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Group('AmazonBraketSimulator3Group', 'Amazon Braket Simulator3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3.md <==
# AmazonBraketSimulator3


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')
```



| Illustration | AmazonBraketSimulator3 | AmazonBraketSimulator3Card | AmazonBraketSimulator3Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3.png) | ![illustration for AmazonBraketSimulator3](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3.Local.png) | ![illustration for AmazonBraketSimulator3Card](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3Card.Local.png) | ![illustration for AmazonBraketSimulator3Group](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3Group.Local.png) |




## AmazonBraketSimulator3

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3('AmazonBraketSimulator3', 'Amazon Braket Simulator3', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3('AmazonBraketSimulator3', 'Amazon Braket Simulator3', 'an optional tech label')
@enduml
```

## AmazonBraketSimulator3Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Card
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Card('AmazonBraketSimulator3Card', 'Amazon Braket Simulator3 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Card
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Card('AmazonBraketSimulator3Card', 'Amazon Braket Simulator3 Card', 'an optional description')
@enduml
```

## AmazonBraketSimulator3Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Group
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Group('AmazonBraketSimulator3Group', 'Amazon Braket Simulator3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator3Group
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator3')

' renders the element
AmazonBraketSimulator3Group('AmazonBraketSimulator3Group', 'Amazon Braket Simulator3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
